Rename ffprobe to avprobe.
authorAnton Khirnov <anton@khirnov.net>
Tue, 26 Jul 2011 17:04:43 +0000 (19:04 +0200)
committerAnton Khirnov <anton@khirnov.net>
Tue, 9 Aug 2011 17:56:24 +0000 (19:56 +0200)
.gitignore
Changelog
Makefile
avprobe.c [moved from ffprobe.c with 98% similarity]
configure
doc/avplay.texi
doc/avprobe.texi [moved from doc/ffprobe.texi with 83% similarity]
doc/ffmpeg.texi
doc/ffserver.texi

index e867470..5fb57b1 100644 (file)
@@ -13,7 +13,7 @@ doc/*.pod
 doxy
 ffmpeg
 avplay
-ffprobe
+avprobe
 ffserver
 libavcodec/*_tablegen
 libavcodec/*_tables.c
index ad3d867..6cdafba 100644 (file)
--- a/Changelog
+++ b/Changelog
@@ -5,7 +5,7 @@ releases are sorted from youngest to oldest.
 version <next>:
 - BWF muxer
 - Flash Screen Video 2 decoder
-- ffplay renamed to avplay
+- ffplay/ffprobe renamed to avplay/avprobe
 
 
 version 0.7:
index 5214f5a..958ef8a 100644 (file)
--- a/Makefile
+++ b/Makefile
@@ -54,7 +54,7 @@ COMPILE_S = $(call COMPILE,AS)
 
 PROGS-$(CONFIG_FFMPEG)   += ffmpeg
 PROGS-$(CONFIG_AVPLAY)   += avplay
-PROGS-$(CONFIG_FFPROBE)  += ffprobe
+PROGS-$(CONFIG_AVPROBE)  += avprobe
 PROGS-$(CONFIG_FFSERVER) += ffserver
 
 PROGS      := $(PROGS-yes:%=%$(EXESUF))
@@ -64,7 +64,7 @@ HOSTPROGS  := $(TESTTOOLS:%=tests/%)
 TOOLS       = qt-faststart trasher
 TOOLS-$(CONFIG_ZLIB) += cws2fws
 
-BASENAMES   = ffmpeg avplay ffprobe ffserver
+BASENAMES   = ffmpeg avplay avprobe ffserver
 ALLPROGS    = $(BASENAMES:%=%$(EXESUF))
 ALLMANPAGES = $(BASENAMES:%=%.1)
 
similarity index 98%
rename from ffprobe.c
rename to avprobe.c
index 2457b06..3843af9 100644 (file)
--- a/configure
+++ b/configure
@@ -82,7 +82,7 @@ Configuration options:
   --disable-doc            do not build documentation
   --disable-ffmpeg         disable ffmpeg build
   --disable-avplay         disable avplay build
-  --disable-ffprobe        disable ffprobe build
+  --disable-avprobe        disable avprobe build
   --disable-ffserver       disable ffserver build
   --disable-avdevice       disable libavdevice build
   --disable-avcodec        disable libavcodec build
@@ -914,7 +914,7 @@ CONFIG_LIST="
     fastdiv
     ffmpeg
     avplay
-    ffprobe
+    avprobe
     ffserver
     fft
     frei0r
@@ -1491,7 +1491,7 @@ ffmpeg_deps="avcodec avformat swscale"
 ffmpeg_select="buffer_filter"
 avplay_deps="avcodec avformat swscale sdl"
 avplay_select="rdft"
-ffprobe_deps="avcodec avformat"
+avprobe_deps="avcodec avformat"
 ffserver_deps="avformat ffm_muxer fork rtp_protocol rtsp_demuxer"
 ffserver_extralibs='$ldl'
 
@@ -1636,7 +1636,7 @@ enable doc
 enable fastdiv
 enable ffmpeg
 enable avplay
-enable ffprobe
+enable avprobe
 enable ffserver
 enable network
 enable optimizations
index 0c74c59..e8446b7 100644 (file)
@@ -170,7 +170,7 @@ Seek to percentage in file corresponding to fraction of width.
 @settitle AVplay media player
 
 @c man begin SEEALSO
-ffmpeg(1), ffprobe(1), ffserver(1) and the Libav HTML documentation
+ffmpeg(1), avprobe(1), ffserver(1) and the Libav HTML documentation
 @c man end
 
 @c man begin AUTHORS
similarity index 83%
rename from doc/ffprobe.texi
rename to doc/avprobe.texi
index 079cf65..003f5e6 100644 (file)
@@ -1,8 +1,8 @@
 \input texinfo @c -*- texinfo -*-
 
-@settitle ffprobe Documentation
+@settitle avprobe Documentation
 @titlepage
-@center @titlefont{ffprobe Documentation}
+@center @titlefont{avprobe Documentation}
 @end titlepage
 
 @top
@@ -15,33 +15,33 @@ The generic syntax is:
 
 @example
 @c man begin SYNOPSIS
-ffprobe [options] [@file{input_file}]
+avprobe [options] [@file{input_file}]
 @c man end
 @end example
 
 @chapter Description
 @c man begin DESCRIPTION
 
-ffprobe gathers information from multimedia streams and prints it in
+avprobe gathers information from multimedia streams and prints it in
 human- and machine-readable fashion.
 
 For example it can be used to check the format of the container used
 by a multimedia stream and the format and type of each media stream
 contained in it.
 
-If a filename is specified in input, ffprobe will try to open and
+If a filename is specified in input, avprobe will try to open and
 probe the file content. If the file cannot be opened or recognized as
 a multimedia file, a positive exit code is returned.
 
-ffprobe may be employed both as a standalone application or in
+avprobe may be employed both as a standalone application or in
 combination with a textual filter, which may perform more
 sophisticated processing, e.g. statistical processing or plotting.
 
-Options are used to list some of the formats supported by ffprobe or
+Options are used to list some of the formats supported by avprobe or
 for specifying which information to display, and for setting how
-ffprobe will show it.
+avprobe will show it.
 
-ffprobe output is designed to be easily parsable by a textual filter,
+avprobe output is designed to be easily parsable by a textual filter,
 and consists of one or more sections of the form:
 @example
 [SECTION]
@@ -118,8 +118,8 @@ with name "STREAM".
 
 @ignore
 
-@setfilename ffprobe
-@settitle ffprobe media prober
+@setfilename avprobe
+@settitle avprobe media prober
 
 @c man begin SEEALSO
 ffmpeg(1), avplay(1), ffserver(1) and the Libav HTML documentation
index 6393516..af9bdcd 100644 (file)
@@ -1079,7 +1079,7 @@ file to which you want to add them.
 @settitle ffmpeg video converter
 
 @c man begin SEEALSO
-avplay(1), ffprobe(1), ffserver(1) and the Libav HTML documentation
+avplay(1), avprobe(1), ffserver(1) and the Libav HTML documentation
 @c man end
 
 @c man begin AUTHORS
index 3d64b79..05e5297 100644 (file)
@@ -265,7 +265,7 @@ rather than as a daemon.
 
 @c man begin SEEALSO
 
-ffmpeg(1), avplay(1), ffprobe(1), the @file{ffmpeg/doc/ffserver.conf}
+ffmpeg(1), avplay(1), avprobe(1), the @file{ffmpeg/doc/ffserver.conf}
 example and the Libav HTML documentation
 @c man end
--- a/ffprobe.c
+++ b/avprobe.c
@@ -1,5 +1,5 @@
 /*
* ffprobe : Simple Media Prober based on the Libav libraries
  * Copyright (c) 2007-2010 Stefano Sabatini
  *
  * This file is part of Libav.
@@ -29,7 +29,7 @@
 #include "libavdevice/avdevice.h"
 #include "cmdutils.h"
 
-const char program_name[] = "ffprobe";
+const char program_name[] = "avprobe";
 const int program_birth_year = 2007;
 
 static int do_show_format  = 0;
@@ -44,7 +44,7 @@ static int use_value_sexagesimal_format = 0;
 /* globals */
 static const OptionDef options[];
 
-/* FFprobe context */
+/* AVprobe context */
 static const char *input_filename;
 static AVInputFormat *iformat = NULL;
 
@@ -327,7 +327,7 @@ static int probe_file(const char *filename)
 static void show_usage(void)
 {
     printf("Simple multimedia streams analyzer\n");
-    printf("usage: ffprobe [OPTIONS] [INPUT_FILE]\n");
+    printf("usage: %s [OPTIONS] [INPUT_FILE]\n", program_name);
     printf("\n");
 }
 
@@ -407,7 +407,7 @@ int main(int argc, char **argv)
     if (!input_filename) {
         show_usage();
         fprintf(stderr, "You have to specify one input file.\n");
-        fprintf(stderr, "Use -h to get full help or, even better, run 'man ffprobe'.\n");
+        fprintf(stderr, "Use -h to get full help or, even better, run 'man %s'.\n", program_name);
         exit(1);
     }
 
@@ -1,5 +1,5 @@
 /*
- * ffprobe : Simple Media Prober based on the Libav libraries
+ * avprobe : Simple Media Prober based on the Libav libraries
  * Copyright (c) 2007-2010 Stefano Sabatini
  *
index 7277409..9134bc5 100755 (executable)